@@ -304,7 +304,7 @@ rtp_stream_t *
 rtp_find_stream_format(address_t src, address_t dst, uint32_t format);
 
 rtp_stream_t *
-rtp_find_stream(address_t src, address_t dst);
+rtp_find_rtcp_stream(address_t src, address_t dst);
 
 rtp_stream_t *
 rtp_find_call_stream(struct sip_call *call, address_t src, address_t dst);
